/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: NewNode.java,v 1.2.2.1 2000/02/13 03:36:40 pmahar Exp $
 */

package org.enhydra.jbuilder.sample.presentation;

import org.enhydra.jbuilder.sample.EnhydraSample;

import org.enhydra.xml.xmlc.XMLCUtil;
import org.enhydra.xml.xmlc.html.HTMLObject;
import org.w3c.dom.*;
import org.w3c.dom.html.*;
import org.openxml.parser.HTMLParser;

import com.lutris.appserver.server.httpPresentation.*;

import java.io.*;

/**
 * <p>
 * This presentation object dynamically creates an HTML page
 * showing the greeting from the application configuration file.
 * </p>
 */
public class NewNode implements HttpPresentation {
  private NewNodeHTML page = null;
  private HttpPresentationComms comms;

 /**
   * Process the Catalog page to see what the shopper wants
   * to do with the selected product. From this page they
   * can register and for each product they can get information,
   * download, or purchase.
   *
   * @param comms
   *   HTTP communications object.
   * @exception Exception
   *   Any exception may be thrown.
   */
  public void run(HttpPresentationComms c)
        throws HttpPresentationException {
    comms = c;
    page = createPage();
    comms.response.writeHTML(page.toDocument());
  }

  public NewNodeHTML createPage()  {
    page = new NewNodeHTML();
    fixupSpan();
    return page;
  }

  private void fixupSpan() {
    HTMLElement element = page.getElementSpanInsertHere();
    String fromFile = readFile();
    setParsedData(page, element, fromFile);
  }

  private String readFile() {
    FileInputStream      fileStream = null;
    InputStreamReader    inReader   = null;
    BufferedReader       buffer     = null;
    ByteArrayInputStream byteIn     = null;

    StringBuffer buf = new StringBuffer();
    String inLine  = null;

    try {
      EnhydraSample app          = (EnhydraSample) comms.application;
      String        textFilename = null;
      textFilename = app.getAppRoot() + File.separator +
         "text" + File.separator + "addme.txt";
      fileStream = new FileInputStream(new File(textFilename));
      inReader   = new InputStreamReader(fileStream);
      buffer     = new BufferedReader(inReader);
      inLine = new String();
      while (inLine != null) {
        inLine = buffer.readLine();
        if (inLine != null) {
          buf.append(inLine);
        }
      }
      buffer.close();
      inReader.close();
      fileStream.close();
    } catch (java.io.IOException e) {
    }
    return buf.toString();
  }


 private boolean setParsedData(HTMLObject owner,
                               HTMLElement element,
                               String text) {
   boolean parsed = false;
   Node parent = element.getParentNode();
   if (text == null) {
     text = new String();
   }
   if (text.indexOf("<") > -1 && text.indexOf(">") > -1) {
     parsed = true;
     XMLCUtil.getFirstText(element).setData("");
     parent.insertBefore(parseTextToNode(owner, text), element);
     parent.removeChild(element);
   } else {
     XMLCUtil.getFirstText(element).setData(text);
   }
   return parsed;
 }

  private Node parseTextToNode(HTMLObject owner, String text) {
    HTMLParser parser   = null;
    Node newNode        = null;
    Element node        = null;
    StringReader reader = new StringReader("<span id=\"textIn\">" + text + "</span>");
    try {
      parser = new HTMLParser(reader, "source");
      node = owner.createElement("span");
      newNode = parser.parseNode(node);
    } catch (java.io.IOException e) {
      e.printStackTrace();
    }
    return newNode;
  }


}


