/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: ExtensionFilter.java,v 1.1.2.5 2000/02/13 03:41:05 pmahar Exp $
 */
package org.enhydra.devsys.swing;

import java.io.File;
import java.util.Vector;
import javax.swing.filechooser.FileFilter;

/**
 * An implementation of FileFilter that filters out all files
 * except for those matching a set of given extensions.
 */
public class ExtensionFilter extends FileFilter {
    private Vector    ext       = new Vector();
    private String    descTitle = new String();

    /**
     * Creates an extension file filter without an extensions set.
     */
    public ExtensionFilter() {
    }

    /**
     * Return true if this file should be shown in a file chooser.
     */
    public boolean accept(File f) {
        boolean acceptFile = false;
        int count = ext.size();
        String fileExt = getExtension(f);
	if (f == null) {
           acceptFile = true;
        } else if (f.isDirectory()) {
	   acceptFile = true;
        } else if (fileExt != null) {
            for (int i = 0 ; i < count; i++ ) {
               String current = (String) ext.elementAt(i);
               if (fileExt.equalsIgnoreCase(current)) {
                 acceptFile = true;
                }
            }
	 }
	return acceptFile;
    }

    /**
     * Return the file extension.
     */
    private String getExtension(File f) {
        String ex = null;
	if (f != null) {
	    String filename = f.getName();
	    int    i = filename.lastIndexOf('.');

	    if (i > 0 && i < filename.length() - 1) {
		ex = filename.substring(i + 1).toLowerCase().trim();
	    }
	}
	return ex;
    }

    /**
     * Adds an an extension to the list of acceptable file
     * types.
     */
    public void addExtension(String e) {
	ext.addElement(e.toLowerCase().trim());
    }
    /**
     * Returns the human readable description of this filter.
     */
    public String getDescription() {
        StringBuffer desc = new StringBuffer();
        desc.append(getDescriptionTitle());
        desc.append(" (");

	if (ext == null) {
            desc.append("*.*");
        } else {
	    desc.append("*.");
            int count = ext.size();
            for (int i = 0 ; i < count; i++ ) {
              desc.append((String) ext.elementAt(i));
  	      if (i < (count-1))  {
		 desc.append(", ");
              }
            }
	}
        desc.append(")");
        return desc.toString();
   }

    /**
     * Sets the portion of the description that does not
     * include extensions.
     */
    public void setDescriptionTitle(String d) {
	this.descTitle = d;
    }

    /**
     * Gets the portion of the description that does not
     * include extensions.
     */
    public String getDescriptionTitle() {
	return descTitle;
    }


}

