/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: CompilePanel.java,v 1.1.2.5 2000/02/13 03:41:11 pmahar Exp $
 */

package org.enhydra.ide.jbuilder.common.wizard.xmlc;

import org.enhydra.devsys.swing.GridBagConstraintsX;
import org.enhydra.ide.jbuilder.common.node.OtterXMLCNode;
import org.enhydra.ide.jbuilder.common.node.OtterProject;
import org.enhydra.ide.jbuilder.common.ProcessLauncher;
import org.enhydra.ide.jbuilder.common.capture.WriteListener;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.beans.Beans;

/**
 * Class declaration
 *
 *
 * @author
 * @version %I%, %G%
 */
public abstract class CompilePanel extends JPanel {
    private OtterXMLCNode[]	nodes          = null;
    private LocalButtonListener buttonListener = null;
    private OtterProject	project = null;
    private JScrollPane		scrollAvailable;
    private JScrollPane		scrollSelected;
    private JLabel		labelAvailable;
    private JLabel		labelSelected;
    private JList		listAvailable;
    private JList		listSelected;
    private JButton		buttonAdd;
    private JButton		buttonAddAll;
    private JButton		buttonRemove;
    private JButton		buttonRemoveAll;
    private GridBagLayout       layoutMain;
    private DefaultListModel    modelAvailable = new DefaultListModel();
    private DefaultListModel    modelSelected = new DefaultListModel();

    /**
     * Constructor declaration
     *
     *
     * @see
     */
    public CompilePanel() {
	try {
	    jbInit();
	    pmInit();
	} catch (Exception e) {
	    e.printStackTrace();
	}
    }

    // /
    // /
    // event methods

    /**
     * Method declaration
     *
     *
     * @see
     */
    protected abstract void startCompile();

    /**
     * Method declaration
     *
     *
     * @see
     */
    protected abstract void fillLists();

    // /
    // /

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    protected DefaultListModel getModelSelected() {
	return modelSelected;
    }

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    protected DefaultListModel getModelAvailable() {
	return modelAvailable;
    }

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    protected OtterProject getProject() {
	return project;
    }

    /**
     * Method declaration
     *
     *
     * @param p
     *
     * @see
     */
    protected void setProject(OtterProject p) {
	project = p;
    }

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    protected OtterXMLCNode[] getNodes() {
	return nodes;
    }

    /**
     * Method declaration
     *
     *
     * @param source
     *
     * @see
     */
    protected void setNodes(OtterXMLCNode[] n) {
	nodes = n;
	fillLists();
	updateCompileButton();
    }

    /**
     * Method declaration
     *
     *
     * @see
     */
    private void pmInit() {
	buttonListener = new LocalButtonListener();

	buttonAdd.addActionListener(buttonListener);
	buttonAddAll.addActionListener(buttonListener);
	buttonRemove.addActionListener(buttonListener);
	buttonRemoveAll.addActionListener(buttonListener);
    }

    /**
     * Method declaration
     *
     *
     * @throws Exception
     *
     * @see
     */
    private void jbInit() throws Exception {
	layoutMain =
	    (GridBagLayout) Beans.instantiate(getClass().getClassLoader(),
					      GridBagLayout.class.getName());
	scrollAvailable =
	    (JScrollPane) Beans.instantiate(getClass().getClassLoader(),
					    JScrollPane.class.getName());
	scrollSelected =
	    (JScrollPane) Beans.instantiate(getClass().getClassLoader(),
					    JScrollPane.class.getName());
	labelAvailable =
	    (JLabel) Beans.instantiate(getClass().getClassLoader(),
				       JLabel.class.getName());
	labelSelected =
	    (JLabel) Beans.instantiate(getClass().getClassLoader(),
				       JLabel.class.getName());
	listAvailable = (JList) Beans.instantiate(getClass().getClassLoader(),
						  JList.class.getName());
	listSelected = (JList) Beans.instantiate(getClass().getClassLoader(),
						 JList.class.getName());
	buttonAdd = (JButton) Beans.instantiate(getClass().getClassLoader(),
						JButton.class.getName());
	buttonAddAll =
	    (JButton) Beans.instantiate(getClass().getClassLoader(),
					JButton.class.getName());
	buttonRemove =
	    (JButton) Beans.instantiate(getClass().getClassLoader(),
					JButton.class.getName());
	buttonRemoveAll =
	    (JButton) Beans.instantiate(getClass().getClassLoader(),
					JButton.class.getName());

	listAvailable.setModel(modelAvailable);
	listSelected.setModel(modelSelected);
	labelAvailable.setText("Available Pages in Project");
	labelSelected.setText("Selected Pages to Compile:");
	buttonAdd.setText(">");
	buttonAddAll.setText(">>");
	buttonRemove.setText("<");
	buttonRemoveAll.setText("<<");
	scrollAvailable.setMaximumSize(new Dimension(200, 200));
	scrollAvailable.setPreferredSize(new Dimension(200, 200));
	scrollSelected.setPreferredSize(new Dimension(200, 200));
	this.setMinimumSize(new Dimension(400, 200));
	this.setPreferredSize(new Dimension(620, 300));
	scrollAvailable.getViewport().add(listAvailable);
	scrollSelected.getViewport().add(listSelected);
	this.setLayout(layoutMain);
	this.add(labelAvailable,
		 new GridBagConstraintsX(0, 0, 1, 1, 0.1, 0.1,
					GridBagConstraints.WEST,
					GridBagConstraints.HORIZONTAL,
					new Insets(5, 5, 2, 5), 0, 0));
	this.add(scrollAvailable,
		 new GridBagConstraintsX(0, 1, 1, 4, 0.1, 0.1,
					GridBagConstraints.WEST,
					GridBagConstraints.NONE,
					new Insets(3, 5, 5, 5), 250, 250));
	this.add(buttonAdd,
		 new GridBagConstraintsX(1, 1, 1, 1, 0.1, 0.1,
					GridBagConstraints.CENTER,
					GridBagConstraints.NONE,
					new Insets(8, 4, 4, 4), 20, 0));
	this.add(buttonAddAll,
		 new GridBagConstraintsX(1, 2, 1, 1, 0.1, 0.1,
					GridBagConstraints.CENTER,
					GridBagConstraints.NONE,
					new Insets(8, 4, 4, 4), 6, 0));
	this.add(buttonRemove,
		 new GridBagConstraintsX(1, 3, 1, 1, 0.1, 0.1,
					GridBagConstraints.SOUTH,
					GridBagConstraints.NONE,
					new Insets(8, 4, 4, 4), 14, 0));
	this.add(buttonRemoveAll,
		 new GridBagConstraintsX(1, 4, 1, 1, 0.1, 0.1,
					GridBagConstraints.CENTER,
					GridBagConstraints.NONE,
					new Insets(8, 4, 4, 4), 6, 0));
	this.add(labelSelected,
		 new GridBagConstraintsX(2, 0, 1, 1, 0.1, 0.1,
					GridBagConstraints.WEST,
					GridBagConstraints.HORIZONTAL,
					new Insets(5, 5, 2, 5), 0, 0));
	this.add(scrollSelected,
		 new GridBagConstraintsX(2, 1, 1, 4, 0.1, 0.1,
					GridBagConstraints.WEST,
					GridBagConstraints.VERTICAL,
					new Insets(3, 5, 5, 5), 250, 250));
    }

    /**
     * Method declaration
     *
     *
     * @see
     */
    private void addSelected() {
	Object[] elements = listAvailable.getSelectedValues();

	for (int i = 0; i < elements.length; i++) {
	    modelSelected.addElement(elements[i]);
	    modelAvailable.removeElement(elements[i]);

	    for (int j = 0; j < getNodes().length; j++) {
		if (getNodes()[j].getFilename().equals(elements[i].toString())) {
		    getNodes()[j].setCompileSelected(true);
		}
	    }
	}

	updateCompileButton();
    }

    /**
     * Method declaration
     *
     *
     * @see
     */
    private void addAllElements() {
	for (int i = 0; i < modelAvailable.size(); i++) {
	    modelSelected.addElement(modelAvailable.elementAt(i));
	}

	modelAvailable.removeAllElements();

	for (int i = 0; i < getNodes().length; i++) {
	    getNodes()[i].setCompileSelected(true);
	}

	updateCompileButton();
    }

    /**
     * Method declaration
     *
     *
     * @see
     */
    private void removeSelected() {
	Object[] elements = listSelected.getSelectedValues();

	for (int i = 0; i < elements.length; i++) {
	    modelAvailable.addElement(elements[i]);
	    modelSelected.removeElement(elements[i]);

	    for (int j = 0; j < getNodes().length; j++) {
		if (getNodes()[j].getFilename().equals(elements[i].toString())) {
		    getNodes()[j].setCompileSelected(false);
		}
	    }
	}

	updateCompileButton();
    }

    /**
     * Method declaration
     *
     *
     * @see
     */
    private void removeAllElements() {
	for (int i = 0; i < modelSelected.size(); i++) {
	    modelAvailable.addElement(modelSelected.elementAt(i));
	}

	modelSelected.removeAllElements();

	for (int i = 0; i < getNodes().length; i++) {
	    getNodes()[i].setCompileSelected(false);
	}

	updateCompileButton();
    }

    /**
     * Method declaration
     *
     *
     * @see
     */
    private void updateCompileButton() {
	boolean enable = modelSelected.size() > 0;

	if (getTopLevelAncestor() instanceof CompileDialog) {
	    ((CompileDialog) getTopLevelAncestor()).setCompileButtonEnabled(enable);
	}
    }

    /**
     * Class declaration
     *
     *
     * @author
     * @version %I%, %G%
     */
    class LocalButtonListener implements ActionListener {

	/**
	 * Method declaration
	 *
	 *
	 * @param event
	 *
	 * @see
	 */
	public void actionPerformed(ActionEvent event) {
	    Object source = event.getSource();

	    if (source == buttonAdd) {
		addSelected();
	    } else if (source == buttonAddAll) {
		addAllElements();
	    } else if (source == buttonRemove) {
		removeSelected();
	    } else if (source == buttonRemoveAll) {
		removeAllElements();
	    }
	}

    }

}



/*--- formatting done in "Sun Java Convention" style on 01-16-2000 ---*/

