/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: OptionPanel.java,v 1.1.2.7 2000/02/13 03:41:12 pmahar Exp $
 */

package org.enhydra.ide.jbuilder.common.wizard.xmlc;

import org.enhydra.devsys.swing.GridBagConstraintsX;
import org.enhydra.ide.jbuilder.common.node.OtterProject;
import javax.swing.*;
import javax.swing.border.*;
import java.awt.*;
import java.beans.*;
import java.awt.event.*;

/**
 * Class declaration
 *
 *
 * @author
 * @version %I%, %G%
 */
public class OptionPanel extends JPanel {
    private boolean active = false;
    private LocalItemListener   itemListener = null;
    private LocalButtonListener buttonListener = null;
    private OtterProject	project = null;
    private GridBagLayout       layoutMain;
    private JPanel		panelJavaSource;
    private GridBagLayout       layoutJavaSource;
    private JCheckBox		checkKeep;
    private JCheckBox		checkCompile;
    private TitledBorder	borderJavaSource;
    private TitledBorder	borderMappings;
    private TitledBorder	borderTrace;
    private JPanel		panelMappings;
    private GridBagLayout       layoutMap;
    private JButton		buttonProjectMap;
    private JPanel		panelTrace;
    private GridBagLayout       layoutTrace;
    private JCheckBox		checkParseInfo;
    private JCheckBox		checkPrintAccessMethods;
    private JCheckBox		checkPrintInfo;
    private JCheckBox		checkDump;
    private JCheckBox		checkVerbose;
    private JCheckBox		checkAddToProject;
    private JComboBox           comboMap;
    private JLabel              labelMap;

    private final String mapAll      = "All";
    private final String mapSelected = "Selected";
    private final String mapNone     = "None";

    /**
     * Constructor declaration
     *
     *
     * @see
     */
    public OptionPanel() {
	try {
	    jbInit();
	    pmInit();
	} catch (Exception e) {
	    e.printStackTrace();
	}
    }

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    public OtterProject getProject() {
	return project;
    }

    /**
     * Method declaration
     *
     *
     * @param p
     *
     * @see
     */
    public void setProject(OtterProject p) {
	project = p;


        if (comboMap.getItemCount() > 0) {
          comboMap.removeAllItems();
        }

	if (project.isCompileJavaAllowed()) {
           // Win32 and JDeveloper
            comboMap.addItem(mapAll);
            comboMap.addItem(mapNone);
            if (project.getMapScope() == OtterProject.MAP_SCOPE_NONE) {
  	      comboMap.setSelectedItem(mapNone);
            } else {
    	      comboMap.setSelectedItem(mapAll);
              project.setMapScope(OtterProject.MAP_SCOPE_ALL);
            }

	    checkCompile.setEnabled(true);
	    checkCompile.setSelected(project.isCompileJavaSelected());
	    checkAddToProject.setEnabled(false);
	    checkAddToProject.setSelected(false);
	} else {
            // Primetime
            comboMap.addItem(mapAll);
            comboMap.addItem(mapSelected);
            comboMap.addItem(mapNone);

            switch (project.getMapScope()) {
              case OtterProject.MAP_SCOPE_NONE:
   	           comboMap.setSelectedItem(mapNone);
                   break;
              case OtterProject.MAP_SCOPE_SELECTED:
 	           comboMap.setSelectedItem(mapSelected);
                   break;
              default:
                   project.setMapScope(OtterProject.MAP_SCOPE_ALL);
	           comboMap.setSelectedItem(mapAll);
                   break;
            }

	    checkCompile.setEnabled(false);
	    checkCompile.setSelected(false);
	    checkAddToProject.setEnabled(false);
	    checkAddToProject.setSelected(true);
	}

        checkKeep.setSelected(true);
	checkKeep.setEnabled(false);

   	checkDump.setSelected(project.isDumpSelected());
	checkParseInfo.setSelected(project.isParseInfoSelected());
	checkPrintAccessMethods.setSelected(project.isPrintAccessMethodsSelected());
	checkPrintInfo.setSelected(project.isPrintInfoSelected());
	checkVerbose.setSelected(project.isVerboseSelected());
        active = true;
    }

    /**
     * Method declaration
     *
     *
     * @see
     */
    private void pmInit() {
	itemListener = new LocalItemListener();

	checkKeep.addItemListener(itemListener);
	checkCompile.addItemListener(itemListener);
	comboMap.addItemListener(itemListener);
	checkDump.addItemListener(itemListener);
	checkParseInfo.addItemListener(itemListener);
	checkPrintAccessMethods.addItemListener(itemListener);
	checkPrintInfo.addItemListener(itemListener);
	checkVerbose.addItemListener(itemListener);

	buttonListener = new LocalButtonListener();

	buttonProjectMap.addActionListener(buttonListener);
    }

    /**
     * Method declaration
     *
     *
     * @throws Exception
     *
     * @see
     */
    private void jbInit() throws Exception {
	layoutMain =
	    (GridBagLayout) Beans.instantiate(getClass().getClassLoader(),
					      GridBagLayout.class.getName());
	panelJavaSource =
	    (JPanel) Beans.instantiate(getClass().getClassLoader(),
				       JPanel.class.getName());
	layoutJavaSource =
	    (GridBagLayout) Beans.instantiate(getClass().getClassLoader(),
					      GridBagLayout.class.getName());
	checkKeep = (JCheckBox) Beans.instantiate(getClass().getClassLoader(),
						  JCheckBox.class.getName());
	checkCompile =
	    (JCheckBox) Beans.instantiate(getClass().getClassLoader(),
					  JCheckBox.class.getName());
	borderJavaSource = new TitledBorder("");
	borderMappings = new TitledBorder("");
	borderTrace = new TitledBorder("");
	panelMappings =
	    (JPanel) Beans.instantiate(getClass().getClassLoader(),
				       JPanel.class.getName());
	layoutMap =
	    (GridBagLayout) Beans.instantiate(getClass().getClassLoader(),
					      GridBagLayout.class.getName());
	buttonProjectMap =
	    (JButton) Beans.instantiate(getClass().getClassLoader(),
					JButton.class.getName());
	panelTrace = (JPanel) Beans.instantiate(getClass().getClassLoader(),
						JPanel.class.getName());
	layoutTrace =
	    (GridBagLayout) Beans.instantiate(getClass().getClassLoader(),
					      GridBagLayout.class.getName());
	checkParseInfo =
	    (JCheckBox) Beans.instantiate(getClass().getClassLoader(),
					  JCheckBox.class.getName());
	checkPrintAccessMethods =
	    (JCheckBox) Beans.instantiate(getClass().getClassLoader(),
					  JCheckBox.class.getName());
	checkPrintInfo =
	    (JCheckBox) Beans.instantiate(getClass().getClassLoader(),
					  JCheckBox.class.getName());
	checkDump = (JCheckBox) Beans.instantiate(getClass().getClassLoader(),
						  JCheckBox.class.getName());
	checkVerbose =
	    (JCheckBox) Beans.instantiate(getClass().getClassLoader(),
					  JCheckBox.class.getName());
	checkAddToProject =
	    (JCheckBox) Beans.instantiate(getClass().getClassLoader(),
					  JCheckBox.class.getName());

	comboMap = (JComboBox) Beans.instantiate(getClass().getClassLoader(), JComboBox.class.getName());
    labelMap = (JLabel) Beans.instantiate(getClass().getClassLoader(), JLabel.class.getName());
    borderJavaSource.setTitle("Generated Java Source");
	borderMappings.setTitle("Mappings");
	borderTrace.setTitle("Trace Options");
	this.setLayout(layoutMain);
	panelJavaSource.setLayout(layoutJavaSource);
	panelJavaSource.setBorder(borderJavaSource);
	panelMappings.setBorder(borderMappings);
	panelTrace.setBorder(borderTrace);
	panelTrace.setLayout(layoutTrace);
	checkKeep.setSelected(true);
	checkKeep.setText("Keep");
	checkCompile.setSelected(true);
	checkCompile.setText("Compile");
	panelMappings.setLayout(layoutMap);
	buttonProjectMap.setText("Edit...");
	checkParseInfo.setText("Parsing details");
	checkParseInfo.setActionCommand("");
	checkPrintInfo.setText("IDs and URLs");
	checkPrintInfo.setActionCommand("Show information about the page object, such as ids and URLs");
	checkDump.setText("DOM tree");
	checkDump.setActionCommand("");
	checkVerbose.setActionCommand("");
	checkVerbose.setText("Compile process");
	checkPrintAccessMethods.setText("Access methods");
	checkAddToProject.setText("Add to Project");
	checkAddToProject.setActionCommand("");
	labelMap.setHorizontalAlignment(SwingConstants.RIGHT);
    labelMap.setText("Map Nodes:");
    comboMap.addItemListener(new java.awt.event.ItemListener() {
      public void itemStateChanged(ItemEvent e) {
        mapScopeChanged();
      }
    });
    this.add(panelJavaSource,
		 new GridBagConstraintsX(0, 1, 1, 1, 0.0, 0.0,
					GridBagConstraints.CENTER,
					GridBagConstraints.BOTH,
					new Insets(5, 5, 5, 5), 5, 5));
	panelJavaSource.add(checkKeep,
			    new GridBagConstraintsX(0, 0, 1, 1, 0.0, 0.0,
						   GridBagConstraints.CENTER,
						   GridBagConstraints.HORIZONTAL,
						   new Insets(5, 5, 5, 5), 5,
						   0));
	panelJavaSource.add(checkAddToProject,
			    new GridBagConstraintsX(1, 0, 1, 1, 0.0, 0.0,
						   GridBagConstraints.CENTER,
						   GridBagConstraints.HORIZONTAL,
						   new Insets(5, 5, 5, 5), 5,
						   0));
	panelJavaSource.add(checkCompile,
			    new GridBagConstraintsX(2, 0, 1, 1, 0.0, 0.0,
						   GridBagConstraints.CENTER,
						   GridBagConstraints.HORIZONTAL,
						   new Insets(5, 5, 5, 5), 5,
						   0));
	this.add(panelMappings,
		 new GridBagConstraintsX(0, 2, 1, 1, 0.0, 0.0,
					GridBagConstraints.CENTER,
					GridBagConstraints.BOTH,
					new Insets(5, 5, 5, 0), 5, 5));
	panelMappings.add(buttonProjectMap, new GridBagConstraintsX(3, 0, 1, 1, 0.0, 0.0
            ,GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
    panelMappings.add(comboMap, new GridBagConstraintsX(1, 0, 1, 1, 0.2, 0.2
            ,GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL, new Insets(5, 5, 5, 5), 0, 0));
    panelMappings.add(labelMap, new GridBagConstraintsX(0, 0, 1, 1, 0.2, 0.2
            ,GridBagConstraints.EAST, GridBagConstraints.HORIZONTAL, new Insets(5, 5, 5, 5), 0, 0));
	this.add(panelTrace,
		 new GridBagConstraintsX(0, 0, 1, 1, 0.0, 0.0,
					GridBagConstraints.CENTER,
					GridBagConstraints.BOTH,
					new Insets(5, 5, 5, 5), 5, 5));
	panelTrace.add(checkPrintInfo,
		       new GridBagConstraintsX(1, 0, 1, 1, 0.0, 0.0,
					      GridBagConstraints.WEST,
					      GridBagConstraints.HORIZONTAL,
					      new Insets(0, 0, 0, 0), 0, 0));
	panelTrace.add(checkParseInfo,
		       new GridBagConstraintsX(1, 1, 1, 1, 0.0, 0.0,
					      GridBagConstraints.WEST,
					      GridBagConstraints.HORIZONTAL,
					      new Insets(5, 5, 5, 5), 5, 0));
	panelTrace.add(checkDump,
		       new GridBagConstraintsX(0, 2, 1, 1, 0.0, 0.0,
					      GridBagConstraints.WEST,
					      GridBagConstraints.HORIZONTAL,
					      new Insets(5, 5, 5, 5), 5, 0));
	panelTrace.add(checkVerbose,
		       new GridBagConstraintsX(0, 1, 1, 1, 0.0, 0.0,
					      GridBagConstraints.CENTER,
					      GridBagConstraints.NONE,
					      new Insets(5, 5, 5, 5), 5, 0));
	panelTrace.add(checkPrintAccessMethods,
		       new GridBagConstraintsX(0, 0, 1, 1, 0.0, 0.0,
					      GridBagConstraints.WEST,
					      GridBagConstraints.HORIZONTAL,
					      new Insets(5, 5, 5, 5), 5, 0));
    }

    /**
     * Method declaration
     *
     *
     * @param event
     *
     * @see
     */
    private void checkCompileStateChanged(ItemEvent event) {
	boolean selected = (event.getStateChange() == ItemEvent.SELECTED);

	project.setCompileJavaSelected(selected);
    }

    /**
     * Method declaration
     *
     *
     * @param event
     *
     * @see
     */
    private void checkKeepStateChanged(ItemEvent event) {
	boolean selected = (event.getStateChange() == ItemEvent.SELECTED);

	project.setKeepJavaSelected(selected);
    }

    /**
     * Method declaration
     *
     *
     * @param event
     *
     * @see
     */
    private void mapScopeChanged() {
        String item = (String)comboMap.getSelectedItem();
        item = item.trim();
        if (project != null && active) {
          if (item.equalsIgnoreCase(mapAll)) {
    	    project.setMapScope(OtterProject.MAP_SCOPE_ALL);
          } else if (item.equalsIgnoreCase(mapSelected)) {
    	    project.setMapScope(OtterProject.MAP_SCOPE_SELECTED);
          } else if (item.equalsIgnoreCase(mapNone)) {
  	    project.setMapScope(OtterProject.MAP_SCOPE_NONE);
          }
        }
    }

    /**
     * Method declaration
     *
     *
     * @param event
     *
     * @see
     */
    private void checkDumpStateChanged(ItemEvent event) {
	boolean selected = (event.getStateChange() == ItemEvent.SELECTED);

	project.setDumpSelected(selected);
    }

    /**
     * Method declaration
     *
     *
     * @param event
     *
     * @see
     */
    private void checkParseInfoStateChanged(ItemEvent event) {
	boolean selected = (event.getStateChange() == ItemEvent.SELECTED);

	project.setParseInfoSelected(selected);
    }

    /**
     * Method declaration
     *
     *
     * @param event
     *
     * @see
     */
    private void checkPrintAccessMethodsStateChanged(ItemEvent event) {
	boolean selected = (event.getStateChange() == ItemEvent.SELECTED);

	project.setPrintAccessMethodsSelected(selected);
    }

    /**
     * Method declaration
     *
     *
     * @param event
     *
     * @see
     */
    private void checkPrintInfoStateChanged(ItemEvent event) {
	boolean selected = (event.getStateChange() == ItemEvent.SELECTED);

	project.setPrintInfoSelected(selected);
    }

    /**
     * Method declaration
     *
     *
     * @param event
     *
     * @see
     */
    private void checkVerboseStateChanged(ItemEvent event) {
	boolean selected = (event.getStateChange() == ItemEvent.SELECTED);

	project.setVerboseSelected(selected);
    }

    /**
     * Class declaration
     *
     *
     * @author
     * @version %I%, %G%
     */
    class LocalItemListener implements ItemListener {

	/**
	 * Method declaration
	 *
	 *
	 * @param event
	 *
	 * @see
	 */
	public void itemStateChanged(ItemEvent event) {
	    Object source = event.getSource();

	    if (source == checkKeep) {
		checkKeepStateChanged(event);
	    } else if (source == checkCompile) {
		checkCompileStateChanged(event);
	    } else if (source == checkDump) {
		checkDumpStateChanged(event);
	    } else if (source == checkParseInfo) {
		checkParseInfoStateChanged(event);
	    } else if (source == checkPrintAccessMethods) {
		checkPrintAccessMethodsStateChanged(event);
	    } else if (source == checkPrintInfo) {
		checkPrintInfoStateChanged(event);
	    } else if (source == checkVerbose) {
		checkVerboseStateChanged(event);
	    }
	}

    }

    /**
     * Method declaration
     *
     *
     * @see
     */
    private void editProjectMap() {
	MapDialog dialog =
	    new MapDialog(((JDialog) this.getTopLevelAncestor()),
			  "Edit Project Map", true);

	dialog.setProject(project);
	dialog.show();
    }

    /**
     * Class declaration
     *
     *
     * @author
     * @version %I%, %G%
     */
    class LocalButtonListener implements ActionListener {

	/**
	 * Method declaration
	 *
	 *
	 * @param event
	 *
	 * @see
	 */
	public void actionPerformed(ActionEvent event) {
	    Object source = event.getSource();

	    if (source == buttonProjectMap) {
		editProjectMap();
	    }
	}

    }


}



/*--- formatting done in "Sun Java Convention" style on 01-16-2000 ---*/

