/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: XMLCRunner.java,v 1.1.2.9 2000/02/13 03:41:12 pmahar Exp $
 */

package org.enhydra.ide.jbuilder.common.wizard.xmlc;

import org.enhydra.ide.jbuilder.common.node.OtterXMLCNode;
import org.enhydra.xml.xmlc.html.HTMLProprietaryTags;
import org.enhydra.xml.xmlc.commands.xmlc.*;
import org.enhydra.xml.xmlc.XMLCUtil;
import org.enhydra.xml.xmlc.XMLCVersion;
import org.enhydra.xml.xmlc.XMLCException;
import org.enhydra.xml.xmlc.compiler.*;
import org.enhydra.xml.xmlc.commands.options.*;
import org.enhydra.xml.xmlc.dom.XMLCDom;
import org.enhydra.xml.xmlc.parsers.*;
import org.w3c.dom.*;
import org.xml.sax.SAXException;
import java.io.*;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Vector;

/**
 * Class derived from the XMLC compiler program for use in this wizard.
 * TODO: Mark may change some things that will require changes to this class.
 */
public class XMLCRunner {

    /*
     * Object containing the parsed standard options.
     */
    private OtterXMLCNode   node;

    /*
     * Document being compiled.
     */
    private Document      document;

    /*
     * Error output.
     */
    private ErrorReporter errorReporter;

    /*
     * Trace and verbose output.
     */
    private PrintWriter   traceWriter = new PrintWriter(System.err, true);

    /*
     * XML DOM management object.
     */
    private XMLCDom       xmlcDom;

    /**
     * Constructor declaration
     *
     *
     * @see
     */
    public XMLCRunner() {}

    /**
     * Method declaration
     *
     *
     * @param tw
     *
     * @see
     */
    public void setTraceWriter(PrintWriter tw) {
	traceWriter = tw;
    }

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    public PrintWriter getTraceWriter() {
	return traceWriter;
    }

    /*
     * Print out a stack trace.  This works around bugs in SAXException that
     * cause printing a stack trace to generate a null pointer exception.  We
     * can't just fix this in the OpenXML source (we did), because other
     * parsers include that same broken class.
     */

    /**
     * Method declaration
     *
     *
     * @param except
     *
     * @see
     */
    private void printStackTrace(Throwable except) {

	// FIXME: needed???
	if (except instanceof SAXException) {
	    Exception except2 = ((SAXException) except).getException();

	    if (except2 != null) {
		except2.printStackTrace();

		return;
	    }
	}

	except.printStackTrace();
    }

    /*
     * Handle an exception, printing the approriate error
     * message.
     */

    /**
     * Method declaration
     *
     *
     * @param except
     *
     * @see
     */
    public void printException(Throwable except) {

	// Must check that options have been parsed before using them.
	if (except instanceof XMLCException) {
	    System.err.println("Error: " + except.getMessage());

	    if ((node.getOptions() != null) && (node.getOptions().getVerbose())) {
		printStackTrace(except);
	    }

	    // If this is result of a java.lang exception, print stack.
	    Throwable cause = ((XMLCException) except).getCause();

	    if ((cause != null)
		    && cause.getClass().getName().startsWith("java.lang.")) {
		printStackTrace(cause);
	    }
	} else if ((except instanceof FileNotFoundException)
		   || (except instanceof IOException)) {
	    System.err.println("Error: " + except.getClass().getName() + ": "
			       + except.getMessage());

	    if ((node.getOptions() != null) && (node.getOptions().getVerbose())) {
		printStackTrace(except);
	    }
	} else {
	    System.err.println("Error: " + except.getClass().getName() + ": "
			       + except.getMessage());
	    printStackTrace(except);
	}

	System.exit(1);
    }

    /*
     * Parse the page into the DOM and perform various checks and edits.
     */

    /**
     * Method declaration
     *
     *
     * @throws FileNotFoundException
     * @throws IOException
     * @throws SAXException
     * @throws XMLCException
     *
     * @see
     */




    /*
     * Parse the page into the DOM and perform various checks and edits.
     */
    private void parsePage()
        throws XMLCException, FileNotFoundException, IOException {
        if (node.getOptions().getVerbose()) {
            traceWriter.println(">>> parsing " + node.getOptions().getSourceDocument());
        }

        Parse parser = new Parse(errorReporter,
                                (node.getOptions().getParseInfo() ? traceWriter : null));
        xmlcDom = parser.parse(node.getOptions());
        document = xmlcDom.getDocument();

        if (node.getOptions().getPrintInfo()) {
            if (node.getOptions().getVerbose()) {
                traceWriter.println(">>> printing document info");
            }
            LocalPrintInfo info = new LocalPrintInfo(document, xmlcDom);
            info.printInfo(traceWriter);
        }


        EditDOM domEditor = new EditDOM();
        domEditor.addURLEdits(node.getOptions().getURLEdits());
        domEditor.addDeleteClasses(node.getOptions().getDeleteElementClasses());
        domEditor.edit(xmlcDom);

        if (node.getOptions().getDump()) {
            if (node.getOptions().getVerbose()) {
                traceWriter.println(">>> dumping document hierarchy");
            }
            XMLCUtil.printNode("DOM hierarchy", document,
                               XMLCUtil.PRINT_ALL,
                               traceWriter);
        }
    }


    /*
     * Generate the Java source files.
     */
    private void generateJavaSource() throws XMLCException, IOException {
        if (node.getOptions().getVerbose()) {
            traceWriter.println(">>> generating code");
        }
        CodeGenerator codeGen =
            new CodeGenerator(node.getOptions(), xmlcDom,
                              (node.getOptions().getPrintAccessMethods() ? traceWriter : null));
        codeGen.generateJavaSource(node.getOptions());
    }

    /*
     * Generate method information without generating code.
     */
    private void generateJavaSourceInfo() throws XMLCException, IOException {
        if (node.getOptions().getVerbose()) {
            traceWriter.println(">>> generating code info without generating source");
        }
        CodeGenerator codeGen =
            new CodeGenerator(node.getOptions(), xmlcDom,
                              (node.getOptions().getPrintAccessMethods() ? traceWriter : null));
    }

    /*
     * Compile the generate source.
     */

    /*
     * Compile the generate source.
     */
    private void compileJavaSource() throws XMLCException {
        if (node.getOptions().getVerbose()) {
            traceWriter.println(">>> compiling code");
        }
        Javac javac = new Javac(node.getOptions().getJavac());
        javac.compile(node.getOptions(),
                      errorReporter,
                      node.getOptions().getVerbose() ? traceWriter : null);
    }

    /**
     * Write the DOM to a file.
    **/
    private void writeDOM() throws IOException {
        String dir = node.getOptions().getDocumentOutput().getParent();
        if (dir != null) {
            new File(dir).mkdirs();
        }
        PrintWriter domOut = new PrintWriter
            (new BufferedOutputStream(new FileOutputStream(node.getOptions().getDocumentOutput())));
        try {
            domOut.println(xmlcDom.toDocument());
        } finally {
            domOut.close();
        }
    }


    /*
     * Generate the Jave source and Compile the page.
     */

/*
     * Generate the Jave source and Compile the page.
     */
    private void compilePage()
        throws XMLCException, FileNotFoundException, IOException {
        try {
            generateJavaSource();
            if (!node.getOptions().getNoCompile()) {
                compileJavaSource();
                if (node.getOptions().getForRecomp()) {
                    node.getOptions().save();
                }
            }
        } finally {
            if (!node.getOptions().getKeep()) {
                if (node.getOptions().getJavaClassSource() != null) {
                    node.getOptions().getJavaClassSource().delete();
                }
                if (node.getOptions().getJavaInterfaceSource() != null) {
                    node.getOptions().getJavaInterfaceSource().delete();
                }
            }
        }
    }

    /**
     * Print the XMLC version number.
     */
    private void printVersion() {
        System.out.println("Enhydra XMLC version " + XMLCVersion.VERSION);
        System.out.println("See http://www.enhydra.org for latest distribution");
    }

    /*
     * Parse arguments and compile the page.
     */

    /**
     * Method declaration
     *
     *
     * @throws FileNotFoundException
     * @throws IOException
     * @throws SAXException
     * @throws XMLCException
     *
     * @see
     */
    public void compile()
	    throws XMLCException, FileNotFoundException, IOException,
		   SAXException {

	// Setup and document parsing.
        node.initProjectOptions();
	if (node.getOptions().getPrintVersion()) {
	    printVersion();

	    if (node.getOptions().getSourceDocument() == null) {
		return;
	    }
	}

	errorReporter =
	    new ErrorReporter(traceWriter,
			      node.getOptions().getSourceDocument().getPath());


	parsePage();

	if (node.getOptions().getDocumentOutput() == null) {
	    compilePage();
	} else {
	    if (node.getOptions().getPrintAccessMethods()) {
		generateJavaSourceInfo();
	    }

	    writeDOM();
	}

	if (node.getOptions().getVerbose()) {
	    traceWriter.println(">>> completed");
	}
    }

    /**
     * Method declaration
     *
     *
     * @param cn
     *
     * @see
     */
    public void setNode(OtterXMLCNode n) {
	node = n;
    }

  private class LocalPrintInfo {
    /**
     * Table URLs.
     */
    private Vector urls = new Vector();


    /**
     * Table of element ids.
     */
    private Vector ids = new Vector();

    /**
     * Construct document info from document.
     */
    public LocalPrintInfo(Document doc, XMLCDom xmlcDom) {
        getNodeInfo(doc, xmlcDom);
    }

    /**
     * Append URLs from an element.
     */
    private void getElementURLs(Element element, XMLCDom xmlcDom) {
        String[] attrs = xmlcDom.getElementURLAttrs(element);
        if (attrs == null) {
            return;  // No URLs in this node.
        }
        for (int idx = 0; idx < attrs.length; idx++) {
            String url = element.getAttribute(attrs[idx]);
            if ((url != null) && (url.length() > 0)) {
                urls.addElement(url);
            }
        }
    }

    /**
     * Recursively scan nodes nodes and accumulate information.
     */
    private void getNodeInfo(Node node, XMLCDom xmlcDom) {
        if (node instanceof Element) {
            Element elem = (Element)node;
            getElementURLs(elem, xmlcDom);
            String id = xmlcDom.getElementId(elem);
            if ((id != null) && (id.length() > 0)) {
                ids.addElement(id + " => "
                               + xmlcDom.nodeClassToInterface(node));
            }
        }

        for (Node child = node.getFirstChild(); child != null;
             child = child.getNextSibling()) {
            getNodeInfo(child, xmlcDom);
        }
    }

    /**
     * Print document information.
     */
    protected void printInfo(PrintWriter out) {
        int idx;

        out.println("Element IDs:");
        for (idx = 0; idx < ids.size(); idx++) {
            out.println("    " + ids.elementAt(idx));
        }
        out.println("Document URLs:");
        for (idx = 0; idx < urls.size(); idx++) {
            out.println("    " + urls.elementAt(idx));
        }
    }
  }

}



/*--- formatting done in "Sun Java Convention" style on 01-16-2000 ---*/

