/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: PrimeProject.java,v 1.1.2.7 2000/02/13 03:41:13 pmahar Exp $
 */

package org.enhydra.ide.jbuilder.primetime.node;

import org.enhydra.ide.jbuilder.common.node.OtterProject;
import org.enhydra.ide.jbuilder.common.node.OtterNodeFactory;
import com.borland.jbuilder.node.JBProject;
import com.borland.primetime.vfs.Url;
import com.borland.jbuilder.paths.PathSet;
import com.borland.jbuilder.paths.PathSetManager;
import java.io.File;

/**
 * Class declaration
 *
 *
 * @author
 * @version %I%, %G%
 */
public class PrimeProject extends OtterProject {
    private JBProject	     nativeProject = null;
    private PrimeNodeFactory factory = null;

    /**
     * Constructor declaration
     *
     *
     * @param project
     *
     * @see
     */
    public PrimeProject(JBProject p) {
	nativeProject = p;
	factory = new PrimeNodeFactory();
    }

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    public Object getNativeProject() {
	return nativeProject;
    }

    /**
     * Method declaration
     *
     *
     * @param o
     *
     * @see
     */
    public void setNativeProject(Object o) {
	nativeProject = (JBProject) o;
    }

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    public Object getNativeNode() {
	return getNativeProject();
    }

    /**
     * Method declaration
     *
     *
     * @param o
     *
     * @see
     */
    public void setNativeNode(Object o) {
	setNativeProject(o);
    }

    public OtterProject getProject() {
      return this;
    }

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    public OtterNodeFactory getNodeFactory() {
	return factory;
    }

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    public boolean isCompileJavaAllowed() {
	return false;
    }

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    public String getName() {
	String name;

	name = nativeProject.getUrl().getName();

	return name;
    }

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    public String getOutputDirectory() {
	String out = File.separator + "myclasses";

	if (nativeProject != null) {
	    out = nativeProject.getPaths().getOutPath().getFile();
	}

	return out;
    }

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    public String getSourcePath() {
	String out = null;
	Url    urlSet[];

	if (nativeProject != null) {
	    urlSet = nativeProject.getPaths().getSourcePath();

	    for (int i = 0; i < urlSet.length; i++) {
		if (out != null) {
		    out += File.pathSeparator;
		}

		out += urlSet[i].getFile();
	    }
	}

	return out;
    }

    /**
     * Method declaration
     *
     *
     * @param pathAsArray
     *
     * @see
     */
    public void setSourcePathArray(String[] pathAsArray) {
	Url urlSet[] = new Url[pathAsArray.length];

	for (int i = 0; i < pathAsArray.length; i++) {
	    urlSet[i] = new Url(new File(pathAsArray[i]));
	}

	nativeProject.getPaths().setSourcePath(urlSet);
    }

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    public String[] getSourcePathArray() {
	String[] pathAsArray = null;
	Url      urlSet[];

	if (nativeProject != null) {
	    urlSet = nativeProject.getPaths().getSourcePath();
	    pathAsArray = new String[urlSet.length];

	    for (int i = 0; i < urlSet.length; i++) {
		pathAsArray[i] = urlSet[i].getFile();
	    }
	}

	return pathAsArray;
    }

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    public String getClassPath() {
	PathSet pathSet;
	Url     urlSet[];
	String  path = null;
	String  libs = null;

	if (nativeProject != null) {
	    libs = getProperty(JBProject.PROPERTY_LIBRARIES);
	    pathSet = PathSetManager.getLibrary(libs);
	    urlSet = pathSet.getFullClassPath();
	    path = Url.getPath(urlSet);
	}

	return path;
    }

    /**
     * Method declaration
     *
     *
     * @param property
     *
     * @return
     *
     * @see
     */
    public String getProperty(String property) {
	String out = null;

	if (nativeProject != null) {
	    out = nativeProject.getProperty(property);
	}

	return out;
    }

    /**
     * Method declaration
     *
     *
     * @param property
     * @param value
     *
     * @see
     */
    public void setProperty(String property, String value) {
	if (nativeProject != null) {
	    nativeProject.setProperty(property, value);
	}
    }

    public void setProperty(String property, int i) {
        String value = Integer.toString(i);
	setProperty(property, value);
    }

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    public String getFilename() {
	return nativeProject.getUrl().getFile();
    }

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    public char getFileSeparatorChar() {
	return '/';
    }

}



/*--- formatting done in "Sun Java Convention" style on 01-16-2000 ---*/

