/*
 * Enhydra Java Application Server
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License.
 *
 * $Id: XMLCWizard.java,v 1.1.2.9 2000/02/13 03:41:14 pmahar Exp $
 */

package org.enhydra.ide.jbuilder.primetime.wizard.xmlc;


import org.enhydra.devsys.swing.IconSet;
import org.enhydra.xml.xmlc.XMLCException;
import org.enhydra.ide.jbuilder.primetime.node.PrimeProject;
import org.enhydra.ide.jbuilder.primetime.node.PrimeHTMLFileNode;
import org.enhydra.ide.jbuilder.common.wizard.xmlc.CompileDialog;
import org.enhydra.ide.jbuilder.common.node.OtterXMLCNode;

import com.borland.jbuilder.node.JBProject;
import com.borland.jbuilder.node.HTMLFileNode;
import com.borland.primetime.node.Node;
import com.borland.primetime.wizard.BasicWizard;
import com.borland.primetime.wizard.Wizard;
import com.borland.primetime.wizard.WizardAction;
import com.borland.primetime.wizard.WizardHost;
import com.borland.primetime.wizard.WizardManager;
import com.borland.primetime.wizard.WizardPage;
import com.borland.primetime.util.VetoException;
import com.borland.primetime.vfs.InvalidUrlException;
import javax.swing.JOptionPane;
import java.io.File;
import java.util.Vector;

/**
 * Class declaration
 *
 *
 * @author
 * @version %I%, %G%
 */
public class XMLCWizard extends BasicWizard {
    private Vector	       sourceVector = new Vector();
    private JBProject	       nativeProject = null;

    public static WizardAction action = new XMLCWizardAction();

    /**
     * Method declaration
     *
     *
     * @param majorVersion
     * @param minorVersion
     *
     * @see
     */
    public static void initOpenTool(byte majorVersion, byte minorVersion) {
	WizardManager.registerWizardAction(action);
    }

    /**
     * Method declaration
     *
     *
     * @param host
     *
     * @return
     *
     * @see
     */
    public WizardPage invokeWizard(WizardHost host) {
	setWizardTitle(getName());
	invoke(host);

	return super.invokeWizard(host);
    }

    /**
     * Method declaration
     *
     *
     * @throws VetoException
     *
     * @see
     */
    protected void finish() throws VetoException {}

    /**
     * Method declaration
     *
     *
     * @return
     *
     * @see
     */
    public static String getName() {
	return "XMLC Compiler Wizard";
    }

    /**
     * Class declaration
     *
     *
     * @author
     * @version %I%, %G%
     */
    static class XMLCWizardAction extends WizardAction {

	/**
	 * Constructor declaration
	 *
	 *
	 * @see
	 */
	public XMLCWizardAction() {
	    super(getName() + "...", 'X',
		  "Compile HTML pages to DOM classes with XMLC",
                  IconSet.getSmallIcon(),
                  IconSet.getLargeIcon(),
		  false);
        }

	/**
	 * Method declaration
	 *
	 *
	 * @return
	 *
	 * @see
	 */
	protected Wizard createWizard() {
	    return new XMLCWizard();
	}

	/**
	 * Method declaration
	 *
	 *
	 * @param source
	 *
	 * @see
	 */
	public void update(Object source) {
	    setEnabled(true);
	}

    }

    ;

    /**
     * Method declaration
     *
     *
     * @param host
     *
     * @see
     */
    private void invoke(WizardHost host) {
	PrimeProject     primeProject = null;
	OtterXMLCNode[]  xmlcNodes    = null;
	CompileDialog dlg = null;

	nativeProject =
	    (JBProject) host.getBrowser().getProjectView().getActiveProject();

	if (nativeProject != null) {
	    try {
		nativeProject.save();
	    } catch (InvalidUrlException e) {
		e.printStackTrace();
	    } catch (java.io.IOException e) {
		e.printStackTrace();
	    }

	    primeProject = new PrimeProject(nativeProject);
	}

	if (isEnhydraAvailable(primeProject.getClassPath())) {
	    readNodes(nativeProject);

	    dlg = new CompileDialog(host.getDialogParent(), getName(), true);
	    xmlcNodes = new OtterXMLCNode[sourceVector.size()];

	    for (int i = 0; i < xmlcNodes.length; i++) {
		xmlcNodes[i] = (OtterXMLCNode) sourceVector.elementAt(i);
	    }

	    dlg.setProject(primeProject);
	    dlg.setNodes(xmlcNodes);
	    dlg.show();
	}
    }

    /**
     * Method declaration
     *
     *
     * @param projectClassPath
     *
     * @return
     *
     * @see
     */
    private boolean isEnhydraAvailable(String projectClassPath) {
	String message = null;

	try {
	    Class testClass = Class.forName(CompileDialog.XMLC_CLASS);
	} catch (java.lang.ClassNotFoundException e) {
	    message = "Enhydra 2.3 not found in classpath. \n"
		      + "Please verify that that the "
		      + "enhydra.jar file is included your classpath.";
	}

	if (message == null) {
    	   if (!nativeProject.getPaths().putClassOnFullPath(CompileDialog.XMLC_CLASS)) {
		message =
		    "The enhydra.jar file is not included in the "
		    + "current project library set.\n"
		    + "Select the Project | Properties menu "
		    + "to add it before using the Enhydra HTML Compiler.\n\n";
	    }
	}

	if (message != null) {
	    JOptionPane.showMessageDialog(null, message);
	}

	return (message == null);
    }

    // recursively read through nodes.

    /**
     * Method declaration
     *
     *
     * @param container
     *
     * @see
     */
    private void readNodes(Node container) {
	String        filename = null;
	OtterXMLCNode xmlcNode = null;
	Node[]        nativeNodes = container.getChildren();
	HTMLFileNode htmlNode = null;
	File	     current = null;
	String       projectPage = nativeProject.getUrl().getFile();

	if (projectPage.length() > 5) {
	    projectPage = projectPage.substring(0, projectPage.length() - 4);
	}

	projectPage += ".html";

	for (int i = 0; i < nativeNodes.length; i++) {
	    if (nativeNodes[i] instanceof HTMLFileNode) {
		htmlNode = (HTMLFileNode) nativeNodes[i];
		filename = htmlNode.getUrl().getFile();
		current = new File(filename);

		if (current.exists()) {
          	    PrimeHTMLFileNode primeNode = null;
		    primeNode = new PrimeHTMLFileNode(htmlNode);
                    try {
                      xmlcNode = new OtterXMLCNode(primeNode);
		      sourceVector.addElement(xmlcNode);
                    } catch (XMLCException e) {
                      e.printStackTrace();
                    }
		}
	    }

	    // } else {
	    // if (! nodes[i].toString().equalsIgnoreCase("RootContainer")) {
	    readNodes(nativeNodes[i]);    // recrusive folder read.

	    // }
	    // }
	}
    }

}



/*--- formatting done in "Sun Java Convention" style on 01-16-2000 ---*/

